==> prismic-1.2.4.tgz: package/README.md <==
[![@nuxtjs/prismic](/docs/static/preview.png)](https://prismic.nuxtjs.org)

# @nuxtjs/prismic

[![npm version][npm-version-src]][npm-version-href] [![Github Actions CI][github-actions-ci-src]][github-actions-ci-href] [![Codecov][codecov-src]][codecov-href] [![License][license-src]][license-href]

> @nuxtjs/prismic lets you easily connect your [Nuxt.js](https://nuxtjs.org) application to your content hosted on [Prismic](https://prismic.io)

- [🎲 &nbsp;Live demo](https://nuxt-prismic.surge.sh) and its [💾 source code](https://github.com/Atinux/nuxt-prismic-showcase)
- [🎬 &nbsp;Demonstration videos](https://prismic.nuxtjs.org/#videos)
- [✨ &nbsp;Release Notes](/CHANGELOG.md)
- [📖 &nbsp;Read the documentation](https://prismic.nuxtjs.org)

## Features

- Injects and configures Prismic SDK
  - [`prismic-javascript`](https://github.com/prismicio/prismic-javascript), the kit allowing you to query [Prismic API](https://prismic.io/docs/vuejs/query-the-api/how-to-query-the-api)
  - [`prismic-dom`](https://github.com/prismicio/prismic-dom), a set of helpers to handle Prismic data
  - [`@prismicio/vue`](https://github.com/prismicio/prismic-vue), a set of Vue.js components to easily display Prismic data
- Sets up [Prismic previews](https://prismic.io/feature/scheduling-and-previews)
- Compact configuration

[📖 Read the documentation](https://prismic.nuxtjs.org)

## Development

1. Clone this repository
2. Install dependencies using `yarn install` or `npm install`
3. Start development server using `yarn dev` or `npm run dev`

## License

[MIT License](./LICENSE)

<!-- Badges -->

[npm-version-src]: https://img.shields.io/npm/v/@nuxtjs/prismic/latest.svg
[npm-version-href]: https://npmjs.com/package/@nuxtjs/prismic
[github-actions-ci-src]: https://github.com/nuxt-community/prismic-module/workflows/ci/badge.svg
[github-actions-ci-href]: https://github.com/nuxt-community/prismic-module/actions?query=workflow%3Aci
[codecov-src]: https://img.shields.io/codecov/c/github/nuxt-community/prismic-module.svg
[codecov-href]: https://codecov.io/gh/nuxt-community/prismic-module
[license-src]: https://img.shields.io/npm/l/@nuxtjs/prismic.svg
[license-href]: https://npmjs.com/package/@nuxtjs/prismic

==> prismic-1.2.5.tgz: package/README.md <==
[![@nuxtjs/prismic](/docs/static/preview.png)](https://prismic.nuxtjs.org)

# @nuxtjs/prismic

[![npm version][npm-version-src]][npm-version-href] [![Github Actions CI][github-actions-ci-src]][github-actions-ci-href] [![Codecov][codecov-src]][codecov-href] [![License][license-src]][license-href]

> @nuxtjs/prismic lets you easily connect your [Nuxt.js](https://nuxtjs.org) application to your content hosted on [Prismic](https://prismic.io)

- [🎲 &nbsp;Live demo](https://nuxt-prismic.surge.sh) and its [💾 source code](https://github.com/Atinux/nuxt-prismic-showcase)
- [🎬 &nbsp;Demonstration videos](https://prismic.nuxtjs.org/#videos)
- [✨ &nbsp;Release Notes](/CHANGELOG.md)
- [📖 &nbsp;Read the documentation](https://prismic.nuxtjs.org)

## Features

- Injects and configures Prismic SDK
  - [`prismic-javascript`](https://github.com/prismicio/prismic-javascript), the kit allowing you to query [Prismic API](https://prismic.io/docs/technologies/query-content-from-cms-nuxtjs)
  - [`prismic-dom`](https://github.com/prismicio/prismic-dom), a set of helpers to handle Prismic data
  - [`@prismicio/vue`](https://github.com/prismicio/prismic-vue), a set of Vue.js components to easily display Prismic data
- Sets up [Prismic previews](https://prismic.io/feature/scheduling-and-previews)
- Compact configuration

[📖 Read the documentation](https://prismic.nuxtjs.org)

## Development

1. Clone this repository
2. Install dependencies using `yarn install` or `npm install`
3. Start development server using `yarn dev` or `npm run dev`

## License

[MIT License](./LICENSE)

<!-- Badges -->

[npm-version-src]: https://img.shields.io/npm/v/@nuxtjs/prismic/latest.svg
[npm-version-href]: https://npmjs.com/package/@nuxtjs/prismic
[github-actions-ci-src]: https://github.com/nuxt-community/prismic-module/workflows/ci/badge.svg
[github-actions-ci-href]: https://github.com/nuxt-community/prismic-module/actions?query=workflow%3Aci
[codecov-src]: https://img.shields.io/codecov/c/github/nuxt-community/prismic-module.svg
[codecov-href]: https://codecov.io/gh/nuxt-community/prismic-module
[license-src]: https://img.shields.io/npm/l/@nuxtjs/prismic.svg
[license-href]: https://npmjs.com/package/@nuxtjs/prismic
